@@ -70,12 +70,12 @@ CallTreeDlg::CallTreeDlg(TQWidget* pParent, const char* szName) :
 	m_pPrefButton->setPixmap(GET_PIXMAP(ButtonPref));
 	
 	// Open the location of a call
-	connect(m_pGraphWidget, SIGNAL(lineRequested(const TQString&, uint)),
-		this, SIGNAL(lineRequested(const TQString&, uint)));
-	connect(m_pCalledWidget, SIGNAL(lineRequested(const TQString&, uint)),
-		this, SIGNAL(lineRequested(const TQString&, uint)));
-	connect(m_pCallingWidget, SIGNAL(lineRequested(const TQString&, uint)),
-		this, SIGNAL(lineRequested(const TQString&, uint)));
+	connect(m_pGraphWidget, TQ_SIGNAL(lineRequested(const TQString&, uint)),
+		this, TQ_SIGNAL(lineRequested(const TQString&, uint)));
+	connect(m_pCalledWidget, TQ_SIGNAL(lineRequested(const TQString&, uint)),
+		this, TQ_SIGNAL(lineRequested(const TQString&, uint)));
+	connect(m_pCallingWidget, TQ_SIGNAL(lineRequested(const TQString&, uint)),
+		this, TQ_SIGNAL(lineRequested(const TQString&, uint)));
 	
 	m_pCallingWidget->setMode(TreeWidget::Calling);
 	
