@@ -46,7 +46,7 @@ class QueryView;
 
 class EditorTabs : public TabWidget
 {
-   Q_OBJECT
+   TQ_OBJECT
    
 public:
 	EditorTabs(TQWidget* pParent = 0, const char* szName = 0);
