@@ -57,12 +57,12 @@ FileView::FileView(TQWidget* pParent, const char* szName, WFlags fl) :
 	
 	// Send the fileRequested() signal whenever a file is selected in either
 	// the list or the tree
-	connect(m_pFileList, SIGNAL(fileRequested(const TQString&, uint)), this,
-		SIGNAL(fileRequested(const TQString&, uint)));
-	connect(m_pFileTree, SIGNAL(doubleClicked(TQListViewItem*)), 
-		this, SLOT(slotTreeItemSelected(TQListViewItem*)));
-	connect(m_pFileTree, SIGNAL(returnPressed(TQListViewItem*)), this, 
-		SLOT(slotTreeItemSelected(TQListViewItem*)));
+	connect(m_pFileList, TQ_SIGNAL(fileRequested(const TQString&, uint)), this,
+		TQ_SIGNAL(fileRequested(const TQString&, uint)));
+	connect(m_pFileTree, TQ_SIGNAL(doubleClicked(TQListViewItem*)), 
+		this, TQ_SLOT(slotTreeItemSelected(TQListViewItem*)));
+	connect(m_pFileTree, TQ_SIGNAL(returnPressed(TQListViewItem*)), this, 
+		TQ_SLOT(slotTreeItemSelected(TQListViewItem*)));
 }
 
 /**
