@@ -137,23 +137,23 @@ GraphWidget::GraphWidget(TQWidget* pParent, const char* szName) :
 	m_pCscope = new CscopeFrontend();
 	
 	// Add records output by the Cscope process
-	connect(m_pCscope, SIGNAL(dataReady(FrontendToken*)), this,
-		SLOT(slotDataReady(FrontendToken*)));
+	connect(m_pCscope, TQ_SIGNAL(dataReady(FrontendToken*)), this,
+		TQ_SLOT(slotDataReady(FrontendToken*)));
 	
 	// Display query progress information
-	connect(m_pCscope, SIGNAL(progress(int, int)), this,
-		SLOT(slotProgress(int, int)));	
+	connect(m_pCscope, TQ_SIGNAL(progress(int, int)), this,
+		TQ_SLOT(slotProgress(int, int)));	
 		
 	// Draw the graph when the process has finished
-	connect(m_pCscope, SIGNAL(finished(uint)), this,
-		SLOT(slotFinished(uint)));
+	connect(m_pCscope, TQ_SIGNAL(finished(uint)), this,
+		TQ_SLOT(slotFinished(uint)));
 	
 	// Show a multi-call node when a query results in too many records
-	connect(m_pCscope, SIGNAL(aborted()), this,
-		SLOT(slotAborted()));
+	connect(m_pCscope, TQ_SIGNAL(aborted()), this,
+		TQ_SLOT(slotAborted()));
 	
 	// Redraw the graph when Dot exits
-	connect(&m_dot, SIGNAL(finished(uint)), this, SLOT(slotDotFinished()));	
+	connect(&m_dot, TQ_SIGNAL(finished(uint)), this, TQ_SLOT(slotDotFinished()));	
 	
 	// Create the node popup menu
 	m_pNodePopup = new TQPopupMenu(this);
@@ -161,38 +161,38 @@ GraphWidget::GraphWidget(TQWidget* pParent, const char* szName) :
 	m_pNodePopup->insertItem(new MenuLabel(i18n("<b>Called Functions</b>"),
 		m_pNodePopup));
 	m_pNodePopup->insertItem(i18n("Show"), this,
-		SLOT(slotShowCalled()));
+		TQ_SLOT(slotShowCalled()));
 	m_pNodePopup->insertItem(i18n("List/Filter..."), this,
-		SLOT(slotListCalled()));
+		TQ_SLOT(slotListCalled()));
 	m_pNodePopup->insertItem(i18n("Hide"), this,
-		SLOT(slotHideCalled()));
+		TQ_SLOT(slotHideCalled()));
 	
 	m_pNodePopup->insertItem(new MenuLabel(i18n("<b>Calling Functions</b>"),
 		m_pNodePopup));
 	m_pNodePopup->insertItem(i18n("Show"), this,
-		SLOT(slotShowCalling()));
+		TQ_SLOT(slotShowCalling()));
 	m_pNodePopup->insertItem(i18n("List/Filter..."), this,
-		SLOT(slotListCalling()));
+		TQ_SLOT(slotListCalling()));
 	m_pNodePopup->insertItem(i18n("Hide"), this,
-		SLOT(slotHideCalling()));
+		TQ_SLOT(slotHideCalling()));
 	
 	m_pNodePopup->insertItem(new MenuLabel(i18n("<b>This Function</b>"),
 		m_pNodePopup));
 	m_pNodePopup->insertItem(i18n("Find Definition"), this,
-		SLOT(slotFindDef()));
-	m_pNodePopup->insertItem(i18n("Remove"), this, SLOT(slotRemoveNode()));
+		TQ_SLOT(slotFindDef()));
+	m_pNodePopup->insertItem(i18n("Remove"), this, TQ_SLOT(slotRemoveNode()));
 		
 	// Create the multi-call node popup menu
 	m_pMultiCallPopup = new TQPopupMenu(this);
 	m_pMultiCallPopup->insertItem(i18n("List..."), this,
-		SLOT(slotMultiCallDetails()));
+		TQ_SLOT(slotMultiCallDetails()));
 	m_pMultiCallPopup->insertSeparator();
 	m_pMultiCallPopup->insertItem(i18n("Remove"), this,
-		SLOT(slotRemoveNode()));
+		TQ_SLOT(slotRemoveNode()));
 	
 	// Create the edge menu
 	m_pEdgePopup = new TQPopupMenu(this);
-	m_pEdgePopup->insertItem(i18n("Open Call"), this, SLOT(slotOpenCall()));
+	m_pEdgePopup->insertItem(i18n("Open Call"), this, TQ_SLOT(slotOpenCall()));
 		
 	(void)new GraphTip(this);
 }
@@ -1085,8 +1085,8 @@ void GraphWidget::slotFindDef()
 	pDlg = new QueryViewDlg(QueryViewDlg::DestroyOnSelect, this);
 	
 	// Display a line when it is selected in the dialogue
-	connect(pDlg, SIGNAL(lineRequested(const TQString&, uint)), this,
-		SIGNAL(lineRequested(const TQString&, uint)));
+	connect(pDlg, TQ_SIGNAL(lineRequested(const TQString&, uint)), this,
+		TQ_SIGNAL(lineRequested(const TQString&, uint)));
 		
 	// Start the query
 	pDlg->query(CscopeFrontend::Definition, pNode->getFunc());
