@@ -47,7 +47,7 @@ class PrefOpt;
 
 class PreferencesDlg : public KDialogBase
 {
-   Q_OBJECT
+   TQ_OBJECT
 
 public: 
 	PreferencesDlg(uint nPage = Frontend, TQWidget* pParent = 0, const char*
