@@ -53,7 +53,7 @@ class ScanProgressDlg;
 class ProjectFilesDlg : public ProjectFilesLayout, public FileListTarget,
 	public FileListSource
 {
-   Q_OBJECT
+   TQ_OBJECT
 
 public: 
 	ProjectFilesDlg(Project*, TQWidget* pParent = 0,	const char* szName = 0);
