@@ -44,7 +44,7 @@ class QueryViewDriver;
  */
 class QueryPage : public QueryPageBase
 {
-   Q_OBJECT
+   TQ_OBJECT
 
 public: 
 	QueryPage(TQWidget* pParent = 0, const char* szName = 0);
