@@ -58,28 +58,28 @@ QueryView::QueryView(TQWidget* pParent, const char* szName) :
 	
 	// A record is selected if it is either double-clicked, or the ENTER
 	// key is pressed while the record is highlighted
-	connect(this, SIGNAL(doubleClicked(TQListViewItem*)), this, 
-		SLOT(slotRecordSelected(TQListViewItem*)));
-	connect(this, SIGNAL(returnPressed(TQListViewItem*)), this, 
-		SLOT(slotRecordSelected(TQListViewItem*)));
+	connect(this, TQ_SIGNAL(doubleClicked(TQListViewItem*)), this, 
+		TQ_SLOT(slotRecordSelected(TQListViewItem*)));
+	connect(this, TQ_SIGNAL(returnPressed(TQListViewItem*)), this, 
+		TQ_SLOT(slotRecordSelected(TQListViewItem*)));
 		
 	// Show the popup-menu when requested
 	connect(this, 
-		SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint&, int)),
-		m_pQueryMenu, SLOT(slotShow(TQListViewItem*, const TQPoint&, int)));
+		TQ_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint&, int)),
+		m_pQueryMenu, TQ_SLOT(slotShow(TQListViewItem*, const TQPoint&, int)));
 		
 	// Handle popup-menu commands
-	connect(m_pQueryMenu, SIGNAL(viewSource(TQListViewItem*)), this,
-		SLOT(slotRecordSelected(TQListViewItem*)));
-	connect(m_pQueryMenu, SIGNAL(findDef(const TQString&)), this,
-		SLOT(slotFindDef(const TQString&)));
-	connect(m_pQueryMenu, SIGNAL(copy(TQListViewItem*, int)), this,
-		SLOT(slotCopy(TQListViewItem*, int)));
-	connect(m_pQueryMenu, SIGNAL(filter(int)), this, SLOT(slotFilter(int)));
-	connect(m_pQueryMenu, SIGNAL(showAll()), this, 
-		SLOT(slotShowAll()));
-	connect(m_pQueryMenu, SIGNAL(remove(TQListViewItem*)), this,
-		SLOT(slotRemoveItem(TQListViewItem*)));
+	connect(m_pQueryMenu, TQ_SIGNAL(viewSource(TQListViewItem*)), this,
+		TQ_SLOT(slotRecordSelected(TQListViewItem*)));
+	connect(m_pQueryMenu, TQ_SIGNAL(findDef(const TQString&)), this,
+		TQ_SLOT(slotFindDef(const TQString&)));
+	connect(m_pQueryMenu, TQ_SIGNAL(copy(TQListViewItem*, int)), this,
+		TQ_SLOT(slotCopy(TQListViewItem*, int)));
+	connect(m_pQueryMenu, TQ_SIGNAL(filter(int)), this, TQ_SLOT(slotFilter(int)));
+	connect(m_pQueryMenu, TQ_SIGNAL(showAll()), this, 
+		TQ_SLOT(slotShowAll()));
+	connect(m_pQueryMenu, TQ_SIGNAL(remove(TQListViewItem*)), this,
+		TQ_SLOT(slotRemoveItem(TQListViewItem*)));
 }
 
 /**
@@ -290,8 +290,8 @@ void QueryView::slotFindDef(const TQString& sFunc)
 	pDlg = new QueryViewDlg(QueryViewDlg::DestroyOnSelect, this);
 	
 	// Display a line when it is selected in the dialogue
-	connect(pDlg, SIGNAL(lineRequested(const TQString&, uint)), this,
-		SIGNAL(lineRequested(const TQString&, uint)));
+	connect(pDlg, TQ_SIGNAL(lineRequested(const TQString&, uint)), this,
+		TQ_SIGNAL(lineRequested(const TQString&, uint)));
 		
 	// Start the query
 	pDlg->query(CscopeFrontend::Definition, sFunc);
