@@ -44,7 +44,7 @@ class QueryView;
  */
 class QueryViewDriver : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
     QueryViewDriver(QueryView*, TQObject* pParent = 0, const char* szName = 0);
