@@ -39,7 +39,7 @@
  */
 class SearchResultsDlg : public SearchResultsLayout
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	SearchResultsDlg(TQWidget* pParent = 0, const char* szName = 0);
