@@ -42,7 +42,7 @@ TabWidget::TabWidget(TQWidget* pParent, const char* szName) :
 	m_pMenu = new TQPopupMenu(this);
 	
 	// Set the current tab based on the menu selection
-	connect(m_pMenu, SIGNAL(activated(int)), this, SLOT(setCurrentPage(int)));
+	connect(m_pMenu, TQ_SIGNAL(activated(int)), this, TQ_SLOT(setCurrentPage(int)));
 	
 	// Create a button at the top-right corner of the tab widget
 	m_pButton = new TQToolButton(this);
@@ -52,7 +52,7 @@ TabWidget::TabWidget(TQWidget* pParent, const char* szName) :
 	setCornerWidget(m_pButton, TopRight);
 	
 	// Show the popup-menu when the button is clicked
-	connect(m_pButton, SIGNAL(clicked()), this, SLOT(slotShowTabList()));
+	connect(m_pButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotShowTabList()));
 }
 
 /**
